@@ -1,7 +1,7 @@
 package Coro::ProcessPool::Process;
-$Coro::ProcessPool::Process::VERSION = '0.26_002'; # TRIAL
+$Coro::ProcessPool::Process::VERSION = '0.26_003'; # TRIAL
 
-$Coro::ProcessPool::Process::VERSION = '0.26002';use strict;
+$Coro::ProcessPool::Process::VERSION = '0.26003';use strict;
 use warnings;
 use Coro;
 use Data::UUID;
@@ -19,7 +19,7 @@ sub worker {
   my %param = @_;
   my $inc   = $param{include} // [];
   my $cmd   = get_command_path;
-  my $args  = get_args;
+  my $args  = get_args(@$inc);
   my $exec  = "$cmd $args";
 
   my ($parent_in, $child_out) = portable_pipe;
@@ -146,7 +146,7 @@ Coro::ProcessPool::Process
 
 =head1 VERSION
 
-version 0.26_002
+version 0.26_003
 
 =head1 AUTHOR
 
